@@ -543,7 +543,7 @@ class DescribeAsyncRequestInfoRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param AsyncRequestId: 异步请求Id
+        :param AsyncRequestId: 异步请求Id，涉及到异步流程的接口返回，如CreateBackupDBInstance
         :type AsyncRequestId: str
         """
         self.AsyncRequestId = None
@@ -997,6 +997,8 @@ class DescribeSlowLogPatternsRequest(AbstractModel):
         :type Offset: int
         :param Limit: 分页大小，最小值为1，最大值为100，默认值为20。
         :type Limit: int
+        :param Format: 慢日志返回格式，可设置为json，不传默认返回原生慢日志格式。
+        :type Format: str
         """
         self.InstanceId = None
         self.StartTime = None
@@ -1004,6 +1006,7 @@ class DescribeSlowLogPatternsRequest(AbstractModel):
         self.SlowMS = None
         self.Offset = None
         self.Limit = None
+        self.Format = None
 
 
     def _deserialize(self, params):
@@ -1013,6 +1016,7 @@ class DescribeSlowLogPatternsRequest(AbstractModel):
         self.SlowMS = params.get("SlowMS")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        self.Format = params.get("Format")
 
 
 class DescribeSlowLogPatternsResponse(AbstractModel):
@@ -1064,6 +1068,8 @@ class DescribeSlowLogsRequest(AbstractModel):
         :type Offset: int
         :param Limit: 分页大小，最小值为1，最大值为100，默认值为20。
         :type Limit: int
+        :param Format: 慢日志返回格式，可设置为json，不传默认返回原生慢日志格式。
+        :type Format: str
         """
         self.InstanceId = None
         self.StartTime = None
@@ -1071,6 +1077,7 @@ class DescribeSlowLogsRequest(AbstractModel):
         self.SlowMS = None
         self.Offset = None
         self.Limit = None
+        self.Format = None
 
 
     def _deserialize(self, params):
@@ -1080,6 +1087,7 @@ class DescribeSlowLogsRequest(AbstractModel):
         self.SlowMS = params.get("SlowMS")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        self.Format = params.get("Format")
 
 
 class DescribeSlowLogsResponse(AbstractModel):
@@ -1363,6 +1371,7 @@ class InstanceChargePrepaid(AbstractModel):
     def __init__(self):
         """
         :param Period: 购买实例的时长，单位：月。取值范围：1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 24, 36。默认为1。
+（InquirePriceRenewDBInstances，RenewDBInstances调用时必填）
         :type Period: int
         :param RenewFlag: 自动续费标识。取值范围：
 NOTIFY_AND_AUTO_RENEW：通知过期且自动续费
@@ -1370,6 +1379,7 @@ NOTIFY_AND_MANUAL_RENEW：通知过期不自动续费
 DISABLE_NOTIFY_AND_MANUAL_RENEW：不通知过期不自动续费
 
 默认取值：NOTIFY_AND_MANUAL_RENEW。若该参数指定为NOTIFY_AND_AUTO_RENEW，在账户余额充足的情况下，实例到期后将按月自动续费。
+（InquirePriceRenewDBInstances，RenewDBInstances调用时必填）
         :type RenewFlag: str
         """
         self.Period = None
